==> CollaboraOffice-Winx64-2025-12-27_00-33.zip: cool/templates/templates.js <==
// Manually edited
	window.CODA_TEMPLATES = [
	{
		"id": "writer-modern-business-letter-sans-serif",
		"name": "Modern Business Letter Sans Serif",
		"type": "writer",
		"category": "writer",
		"path": "templates/files/text/Modern_business_letter_sans_serif.odt",
		"preview": "templates/previews/text/writer-modern-business-letter-sans-serif.png",
		"featured": true
	},
	{
		"id": "writer-modern-business-letter-serif",
		"name": "Modern Business Letter Serif",
		"type": "writer",
		"category": "writer",
		"path": "templates/files/text/Modern_business_letter_serif.odt",
		"preview": "templates/previews/text/writer-modern-business-letter-serif.png",
		"featured": true
	},
	{
		"id": "writer-cv",
		"name": "CV",
		"type": "writer",
		"category": "writer",
		"path": "templates/files/text/CV.odt",
		"preview": "templates/previews/text/writer-cv.png",
		"featured": true
	},
	{
		"id": "writer-resume1page",
		"name": "Resume One Page",
		"type": "writer",
		"category": "writer",
		"path": "templates/files/text/Resume1page.odt",
		"preview": "templates/previews/text/writer-resume1page.png",
		"featured": true
	},
	{
		"id": "writer-styles-default",
		"name": "Default Style",
		"type": "writer",
		"category": "writer",
		"path": "templates/files/text/Default.odt",
		"preview": "templates/previews/text/writer-styles-default.png",
		"featured": false
	},
	{
		"id": "writer-styles-modern",
		"name": "Modern Style",
		"type": "writer",
		"category": "writer",
		"path": "templates/files/text/Modern.odt",
		"preview": "templates/previews/text/writer-styles-modern.png",
		"featured": false
	},
	{
		"id": "writer-styles-simple",
		"name": "Simple Style",
		"type": "writer",
		"category": "writer",
		"path": "templates/files/text/Simple.odt",
		"preview": "templates/previews/text/writer-styles-simple.png",
		"featured": false
	},
	{
		"id": "impress-beehive",
		"name": "Beehive",
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/Beehive.odp",
		"preview": "templates/previews/presentation/impress-beehive.png",
		"featured": false
	},
	{
		"id": "impress-blue-curve",
		"name": "Blue Curve",
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/Blue_Curve.odp",
		"preview": "templates/previews/presentation/impress-blue-curve.png",
		"featured": false
	},
	{
		"id": "impress-blueprint-plans",
		"name": "Blueprint Plans",
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/Blueprint_Plans.odp",
		"preview": "templates/previews/presentation/impress-blueprint-plans.png",
		"featured": false
	},
	{
		"id": "impress-candy",
		"name": "Candy",
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/Candy.odp",
		"preview": "templates/previews/presentation/impress-candy.png",
		"featured": false
	},
	{
		"id": "impress-dna",
		"name": "DNA",
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/DNA.odp",
		"preview": "templates/previews/presentation/impress-dna.png",
		"featured": false
	},
	{
		"id": "impress-focus",
		"name": "Focus",
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/Focus.odp",
		"preview": "templates/previews/presentation/impress-focus.png",
		"featured": false
	},
	{
		"id": "impress-forestbird",
		"name": "Forestbird",
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/Forestbird.odp",
		"preview": "templates/previews/presentation/impress-forestbird.png",
		"featured": false
	},
	{
		"id": "impress-freshes",
		"name": "Freshes",
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/Freshes.odp",
		"preview": "templates/previews/presentation/impress-freshes.png",
		"featured": false
	},
	{
		"id": "impress-grey-elegant",
		"name": "Grey Elegant",
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/Grey_Elegant.odp",
		"preview": "templates/previews/presentation/impress-grey-elegant.png",
		"featured": false
	},
	{
		"id": "impress-growing-liberty",
		"name": "Growing Liberty",
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/Growing_Liberty.odp",
		"preview": "templates/previews/presentation/impress-growing-liberty.png",
		"featured": false
	},
	{
		"id": "impress-inspiration",
		"name": "Inspiration",
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/Inspiration.odp",
		"preview": "templates/previews/presentation/impress-inspiration.png",
		"featured": false
	},
	{
		"id": "impress-lights",
		"name": "Lights",
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/Lights.odp",
		"preview": "templates/previews/presentation/impress-lights.png",
		"featured": false
	},
	{
		"id": "impress-metropolis",
		"name": "Metropolis",
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/Metropolis.odp",
		"preview": "templates/previews/presentation/impress-metropolis.png",
		"featured": false
	},
	{
		"id": "impress-midnightblue",
		"name": "Midnightblue",
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/Midnightblue.odp",
		"preview": "templates/previews/presentation/impress-midnightblue.png",
		"featured": false
	},
	{
		"id": "impress-nature-illustration",
		"name": "Nature Illustration",
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/Nature_Illustration.odp",
		"preview": "templates/previews/presentation/impress-nature-illustration.png",
		"featured": false
	},
	{
		"id": "impress-pencil",
		"name": "Pencil",
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/Pencil.odp",
		"preview": "templates/previews/presentation/impress-pencil.png",
		"featured": false
	},
	{
		"id": "impress-piano",
		"name": "Piano",
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/Piano.odp",
		"preview": "templates/previews/presentation/impress-piano.png",
		"featured": false
	},
	{
		"id": "impress-portfolio",
		"name": "Portfolio",
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/Portfolio.odp",
		"preview": "templates/previews/presentation/impress-portfolio.png",
		"featured": false
	},
	{
		"id": "impress-progress",
		"name": "Progress",
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/Progress.odp",
		"preview": "templates/previews/presentation/impress-progress.png",
		"featured": false
	},
	{
		"id": "impress-sunset",
		"name": "Sunset",
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/Sunset.odp",
		"preview": "templates/previews/presentation/impress-sunset.png",
		"featured": false
	},
	{
		"id": "impress-vintage",
		"name": "Vintage",
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/Vintage.odp",
		"preview": "templates/previews/presentation/impress-vintage.png",
		"featured": false
	},
	{
		"id": "impress-vivid",
		"name": "Vivid",
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/Vivid.odp",
		"preview": "templates/previews/presentation/impress-vivid.png",
		"featured": false
	},
	{
		"id": "impress-yellow-idea",
		"name": "Yellow Idea",
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/Yellow_Idea.odp",
		"preview": "templates/previews/presentation/impress-yellow-idea.png",
		"featured": false
	}
];

==> CollaboraOffice-Winx64-2026-03-03_00-37.zip: cool/templates/templates.js <==
/* -*- js-indent-level: 8; fill-column: 100 -*- */
// Manually edited
window.CODA_TEMPLATES = [
	{
		"id": "writer-modern-business-letter-sans-serif",
		"name": _("Modern Business Letter (sans-serif)"),
		"type": "writer",
		"category": "writer",
		"path": "templates/files/text/Modern_business_letter_sans_serif.odt",
		"basename": _("Business Letter"),
		"preview": "templates/previews/text/writer-modern-business-letter-sans-serif.png",
		"featured": true
	},
	{
		"id": "writer-modern-business-letter-serif",
		"name": _("Modern Business Letter (serif)"),
		"type": "writer",
		"category": "writer",
		"path": "templates/files/text/Modern_business_letter_serif.odt",
		"basename": _("Business Letter"),
		"preview": "templates/previews/text/writer-modern-business-letter-serif.png",
		"featured": true
	},
	{
		"id": "writer-cv",
		"name": _("CV"),
		"type": "writer",
		"category": "writer",
		"path": "templates/files/text/CV.odt",
		"basename": _("CV"),
		"preview": "templates/previews/text/writer-cv.png",
		"featured": true
	},
	{
		"id": "writer-resume1page",
		"name": _("Resume (one-page)"),
		"type": "writer",
		"category": "writer",
		"path": "templates/files/text/Resume1page.odt",
		"basename": _("Resume"),
		"preview": "templates/previews/text/writer-resume1page.png",
		"featured": true
	},
	{
		"id": "writer-styles-default",
		"name": _("Default Style"),
		"type": "writer",
		"category": "writer",
		"path": "templates/files/text/Default.odt",
		"basename": _("Text Document"),
		"preview": "templates/previews/text/writer-styles-default.png",
		"featured": false
	},
	{
		"id": "writer-styles-modern",
		"name": _("Modern Style"),
		"type": "writer",
		"category": "writer",
		"path": "templates/files/text/Modern.odt",
		"basename": _("Text Document"),
		"preview": "templates/previews/text/writer-styles-modern.png",
		"featured": false
	},
	{
		"id": "writer-styles-simple",
		"name": _("Simple Style"),
		"type": "writer",
		"category": "writer",
		"path": "templates/files/text/Simple.odt",
		"basename": _("Text Document"),
		"preview": "templates/previews/text/writer-styles-simple.png",
		"featured": false
	},
	{
		"id": "impress-beehive",
		"name": _("Beehive"),
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/Beehive.odp",
		"basename": _("Presentation"),
		"preview": "templates/previews/presentation/impress-beehive.png",
		"featured": false
	},
	{
		"id": "impress-blue-curve",
		"name": _("Blue Curve"),
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/Blue_Curve.odp",
		"basename": _("Presentation"),
		"preview": "templates/previews/presentation/impress-blue-curve.png",
		"featured": false
	},
	{
		"id": "impress-blueprint-plans",
		"name": _("Blueprint Plans"),
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/Blueprint_Plans.odp",
		"basename": _("Presentation"),
		"preview": "templates/previews/presentation/impress-blueprint-plans.png",
		"featured": false
	},
	{
		"id": "impress-candy",
		"name": _("Candy"),
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/Candy.odp",
		"basename": _("Presentation"),
		"preview": "templates/previews/presentation/impress-candy.png",
		"featured": false
	},
	{
		"id": "impress-dna",
		"name": _("DNA"),
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/DNA.odp",
		"basename": _("Presentation"),
		"preview": "templates/previews/presentation/impress-dna.png",
		"featured": false
	},
	{
		"id": "impress-focus",
		"name": _("Focus"),
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/Focus.odp",
		"basename": _("Presentation"),
		"preview": "templates/previews/presentation/impress-focus.png",
		"featured": false
	},
	{
		"id": "impress-forestbird",
		"name": _("Forestbird"),
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/Forestbird.odp",
		"basename": _("Presentation"),
		"preview": "templates/previews/presentation/impress-forestbird.png",
		"featured": false
	},
	{
		"id": "impress-freshes",
		"name": _("Freshes"),
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/Freshes.odp",
		"basename": _("Presentation"),
		"preview": "templates/previews/presentation/impress-freshes.png",
		"featured": false
	},
	{
		"id": "impress-grey-elegant",
		"name": _("Grey Elegant"),
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/Grey_Elegant.odp",
		"basename": _("Presentation"),
		"preview": "templates/previews/presentation/impress-grey-elegant.png",
		"featured": false
	},
	{
		"id": "impress-growing-liberty",
		"name": _("Growing Liberty"),
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/Growing_Liberty.odp",
		"basename": _("Presentation"),
		"preview": "templates/previews/presentation/impress-growing-liberty.png",
		"featured": false
	},
	{
		"id": "impress-inspiration",
		"name": _("Inspiration"),
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/Inspiration.odp",
		"basename": _("Presentation"),
		"preview": "templates/previews/presentation/impress-inspiration.png",
		"featured": false
	},
	{
		"id": "impress-lights",
		"name": _("Lights"),
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/Lights.odp",
		"basename": _("Presentation"),
		"preview": "templates/previews/presentation/impress-lights.png",
		"featured": false
	},
	{
		"id": "impress-metropolis",
		"name": _("Metropolis"),
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/Metropolis.odp",
		"basename": _("Presentation"),
		"preview": "templates/previews/presentation/impress-metropolis.png",
		"featured": false
	},
	{
		"id": "impress-midnightblue",
		"name": _("Midnight Blue"),
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/Midnightblue.odp",
		"basename": _("Presentation"),
		"preview": "templates/previews/presentation/impress-midnightblue.png",
		"featured": false
	},
	{
		"id": "impress-nature-illustration",
		"name": _("Nature Illustration"),
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/Nature_Illustration.odp",
		"basename": _("Presentation"),
		"preview": "templates/previews/presentation/impress-nature-illustration.png",
		"featured": false
	},
	{
		"id": "impress-pencil",
		"name": _("Pencil"),
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/Pencil.odp",
		"basename": _("Presentation"),
		"preview": "templates/previews/presentation/impress-pencil.png",
		"featured": false
	},
	{
		"id": "impress-piano",
		"name": _("Piano"),
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/Piano.odp",
		"basename": _("Presentation"),
		"preview": "templates/previews/presentation/impress-piano.png",
		"featured": false
	},
	{
		"id": "impress-portfolio",
		"name": _("Portfolio"),
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/Portfolio.odp",
		"basename": _("Presentation"),
		"preview": "templates/previews/presentation/impress-portfolio.png",
		"featured": false
	},
	{
		"id": "impress-progress",
		"name": _("Progress"),
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/Progress.odp",
		"basename": _("Presentation"),
		"preview": "templates/previews/presentation/impress-progress.png",
		"featured": false
	},
	{
		"id": "impress-sunset",
		"name": _("Sunset"),
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/Sunset.odp",
		"basename": _("Presentation"),
		"preview": "templates/previews/presentation/impress-sunset.png",
		"featured": false
	},
	{
		"id": "impress-vintage",
		"name": _("Vintage"),
		"type": "impress",
		"category": "impress",
		"basename": _("Presentation"),
		"path": "templates/files/presentation/Vintage.odp",
		"preview": "templates/previews/presentation/impress-vintage.png",
		"featured": false
	},
	{
		"id": "impress-vivid",
		"name": _("Vivid"),
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/Vivid.odp",
		"basename": _("Presentation"),
		"preview": "templates/previews/presentation/impress-vivid.png",
		"featured": false
	},
	{
		"id": "impress-yellow-idea",
		"name": _("Yellow Idea"),
		"type": "impress",
		"category": "impress",
		"path": "templates/files/presentation/Yellow_Idea.odp",
		"basename": _("Presentation"),
		"preview": "templates/previews/presentation/impress-yellow-idea.png",
		"featured": false
	}
];
